@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class ActivitylibraryConfig(AppConfig):
-    name = 'activityLibrary'
+    name = 'GymBuddyApp.activityLibrary'
